@@ -130,14 +130,16 @@ static inline bool nullfs_unopenable_type(object_file_type_t type)
 fsal_status_t nullfs_close(struct fsal_obj_handle *obj_hdl);
 
 /* Multi-FD */
-fsal_status_t
-nullfs_open2(struct fsal_obj_handle *obj_hdl, struct state_t *state,
-	     fsal_openflags_t openflags, enum fsal_create_mode createmode,
-	     const char *name, struct fsal_attrlist *attrs_in,
-	     fsal_verifier_t verifier, struct fsal_obj_handle **new_obj,
-	     struct fsal_attrlist *attrs_out, bool *caller_perm_check,
-	     struct fsal_attrlist *parent_pre_attrs_out,
-	     struct fsal_attrlist *parent_post_attrs_out);
+fsal_status_t nullfs_open2(struct fsal_obj_handle *obj_hdl,
+			   struct state_t *state, fsal_openflags_t openflags,
+			   enum fsal_create_mode createmode, const char *name,
+			   struct fsal_attrlist *attrs_in,
+			   fsal_verifier_t verifier,
+			   struct fsal_obj_handle **new_obj,
+			   struct fsal_attrlist *attrs_out,
+			   bool *caller_perm_check,
+			   struct fsal_attrlist *parent_pre_attrs_out,
+			   struct fsal_attrlist *parent_post_attrs_out);
 bool nullfs_check_verifier(struct fsal_obj_handle *obj_hdl,
 			   fsal_verifier_t verifier);
 fsal_openflags_t nullfs_status2(struct fsal_obj_handle *obj_hdl,
@@ -168,10 +170,12 @@ fsal_status_t nullfs_fallocate(struct fsal_obj_handle *obj_hdl,
 			       uint64_t length, bool allocate);
 
 /* extended attributes management */
-fsal_status_t
-nullfs_list_ext_attrs(struct fsal_obj_handle *obj_hdl, unsigned int cookie,
-		      fsal_xattrent_t *xattrs_tab, unsigned int xattrs_tabsize,
-		      unsigned int *p_nb_returned, int *end_of_list);
+fsal_status_t nullfs_list_ext_attrs(struct fsal_obj_handle *obj_hdl,
+				    unsigned int cookie,
+				    fsal_xattrent_t *xattrs_tab,
+				    unsigned int xattrs_tabsize,
+				    unsigned int *p_nb_returned,
+				    int *end_of_list);
 fsal_status_t nullfs_getextattr_id_by_name(struct fsal_obj_handle *obj_hdl,
 					   const char *xattr_name,
 					   unsigned int *pxattr_id);
