@@ -111,8 +111,9 @@ enum nfs_req_result nfs4_op_setattr(struct nfs_argop4 *op,
 	}
 
 	/* Convert the fattr4 in the request to a fsal sattr structure */
-	res_SETATTR4->status = nfs4_Fattr_To_FSAL_attr(
-		&sattr, &arg_SETATTR4->obj_attributes, data);
+	res_SETATTR4->status =
+		nfs4_Fattr_To_FSAL_attr(&sattr, &arg_SETATTR4->obj_attributes,
+					data);
 
 	if (res_SETATTR4->status != NFS4_OK)
 		goto done;
