@@ -93,6 +93,7 @@ extern uint32_t root_op_export_set;
  * cluster implementation.
  */
 extern int g_nodeid;
+extern char *g_node_vip;
 
 void init_ctx_refstr(void);
 void destroy_ctx_refstr(void);
@@ -132,6 +133,19 @@ void set_op_context_pnfs_ds(struct fsal_pnfs_ds *pds);
  * used by nfs_main to initialize fsal modules.
  */
 
+/**
+ * @brief Start a static FSAL
+ *
+ * Start a FSAL that's statically linked in.
+ *
+ * @param[in]  name	    FSAL name
+ * @param[in]  init	    Initialization function for FSAL
+ * @param[out] fsal_hdl FSAL handle
+ */
+
+void load_fsal_static(const char *name, void (*init)(void),
+		      struct fsal_module **fsal_hdl);
+
 /* Called only within MODULE_INIT and MODULE_FINI functions of a fsal
  * module
  */
@@ -157,6 +171,7 @@ void set_op_context_pnfs_ds(struct fsal_pnfs_ds *pds);
 int register_fsal(struct fsal_module *fsal_hdl, const char *name,
 		  uint32_t major_version, uint32_t minor_version,
 		  uint8_t fsal_id);
+
 /**
  * @brief Unregister an FSAL
  *
@@ -315,6 +330,7 @@ fsal_status_t fsal_readdir(struct fsal_obj_handle *directory, uint64_t cookie,
 			   unsigned int *nbfound, bool *eod_met,
 			   attrmask_t attrmask, helper_readdir_cb cb,
 			   void *opaque);
+bool fsal_has_file_states(struct fsal_obj_handle *obj_hdl);
 fsal_status_t fsal_remove(struct fsal_obj_handle *parent, const char *name,
 			  struct fsal_attrlist *parent_pre_attrs_out,
 			  struct fsal_attrlist *parent_post_attrs_out);
