@@ -831,6 +831,8 @@ static inline fsal_status_t fsalstat(fsal_errors_t major, int minor)
  */
 #define FSAL_IS_SUCCESS(_status_) ((_status_).major == ERR_FSAL_NO_ERROR)
 #define FSAL_IS_ERROR(_status_) (!FSAL_IS_SUCCESS(_status_))
+#define FSAL_IS_PERMISSION_ERR(s) \
+	((s).major == ERR_FSAL_ACCESS || (s).major == ERR_FSAL_PERM)
 
 /**
  * @brief File system dynamic info.
