@@ -229,7 +229,9 @@ typedef enum protos {
 #define UDP_LISTENER_NONE 0
 #define UDP_LISTENER_ALL 0x00000001
 #define UDP_LISTENER_MOUNT 0x00000002
-#define UDP_LISTENER_MASK (UDP_LISTENER_ALL | UDP_LISTENER_MOUNT)
+#define UDP_LISTENER_NLM 0x00000004
+#define UDP_LISTENER_MASK \
+	(UDP_LISTENER_ALL | UDP_LISTENER_MOUNT | UDP_LISTENER_NLM)
 
 #define ROOT_KERBEROS_PRINCIPAL_NONE (1 << 0)
 #define ROOT_KERBEROS_PRINCIPAL_NFS (1 << 1)
