@@ -35,7 +35,12 @@
 #include <streambuf>
 #include <mutex>
 
+#ifdef HAVE_PROCPS
+#include <proc/readproc.h>
+#endif
+
 #include "prometheus_exposer.h"
+#include "dynamic_metrics.h"
 
 #ifdef USE_MONITORING
 
@@ -302,6 +307,10 @@ void *PrometheusExposer::server_thread(void *arg)
 			exposer->failureLatencies_.Observe(elapsed_ms);
 		else
 			exposer->successLatencies_.Observe(elapsed_ms);
+
+#ifdef HAVE_PROCPS
+		update_mem_info();
+#endif
 	}
 	return NULL;
 }
@@ -334,6 +343,23 @@ void prometheus_exposer__stop(prometheus_registry_handle_t registry_handle)
 	stopped = true;
 }
 
+#ifdef HAVE_PROCPS
+void update_mem_info()
+{
+	pid_t ganesha_pid;
+	ganesha_pid = getpid();
+	pid_t pids[] = { ganesha_pid, 0 };
+	PROCTAB *proc = openproc(PROC_FILLMEM | PROC_FILLSTATUS |
+					 PROC_FILLSTAT | PROC_PID,
+				 pids);
+	proc_t proc_info;
+	memset(&proc_info, 0, sizeof(proc_info));
+
+	if (readproc(proc, &proc_info) != NULL)
+		dynamic_metrics__mem_info(proc_info);
+}
+#endif
+
 } /* extern "C" */
 
 } /* namespace ganesha_monitoring */
