@@ -207,62 +207,6 @@ int ip_str_to_sockaddr(char *ip_str, sockaddr_t *sp)
 	return ret;
 }
 
-/**
- *
- * @brief Compare 2 sockaddrs, including ports
- *
- * @param[in] addr_1      First address
- * @param[in] addr_2      Second address
- * @param[in] ignore_port Whether to ignore the port
- *
- * @return Comparator true/false,
- */
-int cmp_sockaddr(sockaddr_t *addr_1, sockaddr_t *addr_2, bool ignore_port)
-{
-	sockaddr_t addr_ipv4_1 = {};
-	sockaddr_t addr_ipv4_2 = {};
-
-	if (addr_1->ss_family != addr_2->ss_family) {
-		addr_1 = convert_ipv6_to_ipv4(addr_1, &addr_ipv4_1);
-		addr_2 = convert_ipv6_to_ipv4(addr_2, &addr_ipv4_2);
-	}
-
-	if (addr_1->ss_family != addr_2->ss_family)
-		return 0;
-
-	switch (addr_1->ss_family) {
-	case AF_INET: {
-		struct sockaddr_in *inaddr1 = (struct sockaddr_in *)addr_1;
-		struct sockaddr_in *inaddr2 = (struct sockaddr_in *)addr_2;
-
-		return (inaddr1->sin_addr.s_addr == inaddr2->sin_addr.s_addr &&
-			(ignore_port ||
-			 inaddr1->sin_port == inaddr2->sin_port));
-	}
-	case AF_INET6: {
-		struct sockaddr_in6 *ip6addr1 = (struct sockaddr_in6 *)addr_1;
-		struct sockaddr_in6 *ip6addr2 = (struct sockaddr_in6 *)addr_2;
-
-		return (memcmp(ip6addr1->sin6_addr.s6_addr,
-			       ip6addr2->sin6_addr.s6_addr,
-			       sizeof(ip6addr2->sin6_addr.s6_addr)) == 0) &&
-		       (ignore_port ||
-			ip6addr1->sin6_port == ip6addr2->sin6_port);
-	} break;
-#ifdef RPC_VSOCK
-	case AF_VSOCK: {
-		struct sockaddr_vm *svm1 = (struct sockaddr_vm *)addr_1;
-		struct sockaddr_vm *svm2 = (struct sockaddr_vm *)addr_2;
-
-		return (svm1->svm_cid == svm2->svm_cid &&
-			(ignore_port || svm1->svm_port == svm2->svm_port));
-	} break;
-#endif /* VSOCK */
-	default:
-		return 0;
-	}
-}
-
 /**
  * @brief Canonically compare 2 sockaddrs
  *
@@ -274,6 +218,13 @@ int cmp_sockaddr(sockaddr_t *addr_1, sockaddr_t *addr_2, bool ignore_port)
  */
 int sockaddr_cmpf(sockaddr_t *addr1, sockaddr_t *addr2, bool ignore_port)
 {
+	sockaddr_t addr_ipv4_1 = {};
+	sockaddr_t addr_ipv4_2 = {};
+
+	if (addr1->ss_family != addr2->ss_family) {
+		addr1 = convert_ipv6_to_ipv4(addr1, &addr_ipv4_1);
+		addr2 = convert_ipv6_to_ipv4(addr2, &addr_ipv4_2);
+	}
 	switch (addr1->ss_family) {
 	case AF_INET: {
 		struct sockaddr_in *in1 = (struct sockaddr_in *)addr1;
@@ -339,6 +290,21 @@ int sockaddr_cmpf(sockaddr_t *addr1, sockaddr_t *addr2, bool ignore_port)
 	}
 }
 
+/**
+ *
+ * @brief Compare 2 sockaddrs, including ports
+ *
+ * @param[in] addr_1      First address
+ * @param[in] addr_2      Second address
+ * @param[in] ignore_port Whether to ignore the port
+ *
+ * @return Comparator true/false,
+ */
+int cmp_sockaddr(sockaddr_t *addr_1, sockaddr_t *addr_2, bool ignore_port)
+{
+	return (sockaddr_cmpf(addr_1, addr_2, ignore_port) == 0);
+}
+
 int get_port(sockaddr_t *addr)
 {
 	switch (addr->ss_family) {
